searchData={"items":[{"type":"module","title":"Cldr.Territory","doc":"Supports the CLDR Territories definitions which provide the localization of many\nterritories.","ref":"Cldr.Territory.html"},{"type":"function","title":"Cldr.Territory.available_styles/0","doc":"Returns a list of available styles.","ref":"Cldr.Territory.html#available_styles/0"},{"type":"function","title":"Example - Cldr.Territory.available_styles/0","doc":"iex> Cldr.Territory.available_styles()\n    [:short, :standard, :variant]","ref":"Cldr.Territory.html#available_styles/0-example"},{"type":"function","title":"Cldr.Territory.available_subdivisions/1","doc":"Returns the available territory subdivisions for a given locale.\n\n* `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/1`","ref":"Cldr.Territory.html#available_subdivisions/1"},{"type":"function","title":"Example - Cldr.Territory.available_subdivisions/1","doc":"=> Cldr.Territory.available_subdivisions(TestBackend.Cldr)\n    [\"ad02\", \"ad03\", \"ad04\", \"ad05\", \"ad06\", \"ad07\", \"ad08\", ...]","ref":"Cldr.Territory.html#available_subdivisions/1-example"},{"type":"function","title":"Cldr.Territory.available_territories/1","doc":"Returns the available territories for a given locale.\n\n* `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/1`","ref":"Cldr.Territory.html#available_territories/1"},{"type":"function","title":"Example - Cldr.Territory.available_territories/1","doc":"=> Cldr.Territory.available_territories(TestBackend.Cldr)\n    [:\"001\", :\"002\", :\"003\", :\"005\", :\"009\", :\"011\", :\"013\", :\"014\", :\"015\", :\"017\",\n    :\"018\", :\"019\", :\"021\", :\"029\", :\"030\", :\"034\", :\"035\", :\"039\", :\"053\", :\"054\",\n    :\"057\", :\"061\", :\"142\", :\"143\", :\"145\", :\"150\", :\"151\", :\"154\", :\"155\", :\"202\",\n    :\"419\", :AC, :AD, :AE, :AF, :AG, :AI, :AL, :AM, :AO, :AQ, :AR, :AS, :AT, :AU,\n    :AW, :AX, :AZ, :BA, :BB, ...]","ref":"Cldr.Territory.html#available_territories/1-example"},{"type":"function","title":"Cldr.Territory.children/2","doc":"Lists children(s) for the given territory code.\nReturns `{:ok, list}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#children/2"},{"type":"function","title":"Example - Cldr.Territory.children/2","doc":"iex> Cldr.Territory.children(:EU)\n    {:ok,\n     [:AT, :BE, :CY, :CZ, :DE, :DK, :EE, :ES, :FI, :FR, :GR, :HR, :HU, :IE,\n      :IT, :LT, :LU, :LV, :MT, :NL, :PL, :PT, :SE, :SI, :SK, :BG, :RO]}\n\n    iex> Cldr.Territory.children(:ZZZ)\n    {:error, {Cldr.UnknownTerritoryError, \"The territory :ZZZ is unknown\"}}\n\n    iex> Cldr.Territory.children(:GB)\n    {:error, {Cldr.UnknownParentError, \"The territory :GB has no children\"}}","ref":"Cldr.Territory.html#children/2-example"},{"type":"function","title":"Cldr.Territory.children!/2","doc":"The same as `children/2`, but raises an exception if it fails.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#children!/2"},{"type":"function","title":"Example - Cldr.Territory.children!/2","doc":"iex> Cldr.Territory.children!(:EU)\n    [:AT, :BE, :CY, :CZ, :DE, :DK, :EE, :ES, :FI, :FR, :GR, :HR, :HU, :IE, :IT,\n     :LT, :LU, :LV, :MT, :NL, :PL, :PT, :SE, :SI, :SK, :BG, :RO]","ref":"Cldr.Territory.html#children!/2-example"},{"type":"function","title":"Cldr.Territory.contains?/2","doc":"Checks relationship between two territories, where the first argument is the `parent` and second the `child`.\nReturns `true` if successful, otherwise `false`.","ref":"Cldr.Territory.html#contains?/2"},{"type":"function","title":"Example - Cldr.Territory.contains?/2","doc":"iex> Cldr.Territory.contains?(:EU, :DK)\n    true\n\n    iex> Cldr.Territory.contains?(:DK, :EU)\n    false","ref":"Cldr.Territory.html#contains?/2-example"},{"type":"function","title":"Cldr.Territory.country_codes/1","doc":"Returns a list of country codes.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#country_codes/1"},{"type":"function","title":"Example - Cldr.Territory.country_codes/1","doc":"=> Cldr.Territory.country_codes()\n    [:AD, :AE, :AF, :AG, :AI, :AL, :AM, :AO, :AR, :AS, :AT, :AU, :AW,\n     :AX, :AZ, :BA, :BB, :BD, :BE, :BF, :BG, :BH, :BI, :BJ, :BL, :BM,\n     :BN, :BO, :BQ, :BR, :BS, :BT, :BV, :BW, :BY, :BZ, :CA, :CC, :CD,\n     :CF, :CG, :CH, :CI, :CK, :CL, :CM, :CN, :CO, :CR, :CU, ...]","ref":"Cldr.Territory.html#country_codes/1-example"},{"type":"function","title":"Cldr.Territory.display_name/2","doc":"Returns the display name for the given territory code.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n    The default is `Cldr.get_locale/1`\n\n  * `backend` is any Cldr backend module. The default is\n    `Cldr.default_backend!/0`\n\n  * `style` is one of those returned by `Cldr.Territory.available_styles/0`.\n    The current styles are `:short`, `:standard` and `:variant`.\n    The default is `:standard`\n\nIf no `:backend` option is specified and no default backend is\nconfigured an exception will be raised.","ref":"Cldr.Territory.html#display_name/2"},{"type":"function","title":"Example - Cldr.Territory.display_name/2","doc":"iex> Cldr.Territory.display_name(:GB, backend: TestBackend.Cldr)\n    {:ok, \"United Kingdom\"}\n\n    iex> Cldr.put_default_backend(TestBackend.Cldr)\n    iex> Cldr.Territory.display_name(:GB)\n    {:ok, \"United Kingdom\"}\n\n    iex> Cldr.Territory.display_name(:GB, locale: \"pt\")\n    {:ok, \"Reino Unido\"}","ref":"Cldr.Territory.html#display_name/2-example"},{"type":"function","title":"Cldr.Territory.from_language_tag/3","doc":"Localized string for the given `LanguageTag.t`.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `style` is one of those returned by `Cldr.Territory.available_styles/0`.\n    The current styles are `:short`, `:standard` and `:variant`.\n    The default is `:standard`","ref":"Cldr.Territory.html#from_language_tag/3"},{"type":"function","title":"Example - Cldr.Territory.from_language_tag/3","doc":"iex> Cldr.Territory.from_language_tag(Cldr.get_locale(TestBackend.Cldr), TestBackend.Cldr)\n    {:ok, \"world\"}\n\n    iex> Cldr.Territory.from_language_tag(Cldr.get_locale(TestBackend.Cldr), TestBackend.Cldr, [style: :short])\n    {:error, {Cldr.UnknownStyleError, \"The style :short is unknown\"}}\n\n    iex> Cldr.Territory.from_language_tag(Cldr.get_locale(TestBackend.Cldr), TestBackend.Cldr, [style: :ZZZ])\n    {:error, {Cldr.UnknownStyleError, \"The style :ZZZ is unknown\"}}\n\n    iex> Cldr.Territory.from_language_tag(Cldr.get_locale(TestBackend.Cldr), TestBackend.Cldr, [style: \"ZZZ\"])\n    {:error, {Cldr.UnknownStyleError, \"The style \\\"ZZZ\\\" is unknown\"}}","ref":"Cldr.Territory.html#from_language_tag/3-example"},{"type":"function","title":"Cldr.Territory.from_language_tag!/3","doc":"The same as `from_language_tag/2`, but raises an exception if it fails.","ref":"Cldr.Territory.html#from_language_tag!/3"},{"type":"function","title":"Example - Cldr.Territory.from_language_tag!/3","doc":"iex> Cldr.Territory.from_language_tag!(Cldr.get_locale(TestBackend.Cldr), TestBackend.Cldr)\n    \"world\"","ref":"Cldr.Territory.html#from_language_tag!/3-example"},{"type":"function","title":"Cldr.Territory.from_subdivision_code/3","doc":"Localized string for the given subdivision code.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n    The default is `Cldr.get_locale/1`\n\n  * `style` is one of those returned by `Cldr.Territory.available_styles/0`.\n    The current styles are `:short`, `:standard` and `:variant`.\n    The default is `:standard`","ref":"Cldr.Territory.html#from_subdivision_code/3"},{"type":"function","title":"Example - Cldr.Territory.from_subdivision_code/3","doc":"iex> Cldr.Territory.from_subdivision_code(\"gbcma\", TestBackend.Cldr, locale: \"en\")\n    {:ok, \"Cumbria\"}\n\n    iex> Cldr.Territory.from_subdivision_code(\"gbcma\", TestBackend.Cldr, locale: \"pl\")\n    {:ok, \"Kumbria\"}\n\n    iex> Cldr.Territory.from_subdivision_code(\"gbcma\", TestBackend.Cldr, locale: \"bs\")\n    {:error, {Cldr.UnknownSubdivisionError, \"No subdivision translation for :gbcma could be found in locale :bs\"}}\n\n    iex> Cldr.Territory.from_subdivision_code(\"invalid\", TestBackend.Cldr, locale: \"en\")\n    {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"invalid\\\" is unknown\"}}\n\n    iex> Cldr.Territory.from_subdivision_code(\"gbcma\", TestBackend.Cldr, [locale: :zzz])\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}\n\n    iex> Cldr.Territory.from_subdivision_code(\"gbcma\", TestBackend.Cldr, [locale: \"zzz\"])\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"Cldr.Territory.html#from_subdivision_code/3-example"},{"type":"function","title":"Cldr.Territory.from_subdivision_code!/3","doc":"The same as `from_subdivision_code/2`, but raises an exception if it fails.","ref":"Cldr.Territory.html#from_subdivision_code!/3"},{"type":"function","title":"Example - Cldr.Territory.from_subdivision_code!/3","doc":"iex> Cldr.Territory.from_subdivision_code!(\"gbcma\", TestBackend.Cldr, locale: \"en\")\n    \"Cumbria\"\n\n    iex> Cldr.Territory.from_subdivision_code!(\"gbcma\", TestBackend.Cldr, locale: \"pl\")\n    \"Kumbria\"","ref":"Cldr.Territory.html#from_subdivision_code!/3-example"},{"type":"function","title":"Cldr.Territory.from_territory_code/3","doc":"Localized string for the given territory code.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n    The default is `Cldr.get_locale/1`\n\n  * `style` is one of those returned by `Cldr.Territory.available_styles/0`.\n    The current styles are `:short`, `:standard` and `:variant`.\n    The default is `:standard`","ref":"Cldr.Territory.html#from_territory_code/3"},{"type":"function","title":"Example - Cldr.Territory.from_territory_code/3","doc":"iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr)\n    {:ok, \"United Kingdom\"}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [style: :short])\n    {:ok, \"UK\"}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [style: :ZZZ])\n    {:error, {Cldr.UnknownStyleError, \"The style :ZZZ is unknown\"}}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [style: \"ZZZ\"])\n    {:error, {Cldr.UnknownStyleError, \"The style \\\"ZZZ\\\" is unknown\"}}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [locale: \"pt\"])\n    {:ok, \"Reino Unido\"}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [locale: :zzz])\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}\n\n    iex> Cldr.Territory.from_territory_code(:GB, TestBackend.Cldr, [locale: \"zzz\"])\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"Cldr.Territory.html#from_territory_code/3-example"},{"type":"function","title":"Cldr.Territory.from_territory_code!/3","doc":"The same as `from_territory_code/2`, but raises an exception if it fails.","ref":"Cldr.Territory.html#from_territory_code!/3"},{"type":"function","title":"Example - Cldr.Territory.from_territory_code!/3","doc":"iex> Cldr.Territory.from_territory_code!(:GB, TestBackend.Cldr)\n    \"United Kingdom\"\n\n    iex> Cldr.Territory.from_territory_code!(:GB, TestBackend.Cldr, [style: :short])\n    \"UK\"\n\n    iex> Cldr.Territory.from_territory_code!(:GB, TestBackend.Cldr, [locale: \"pt\"])\n    \"Reino Unido\"","ref":"Cldr.Territory.html#from_territory_code!/3-example"},{"type":"function","title":"Cldr.Territory.info/1","doc":"Maps territory info for the given territory code.\nReturns `{:ok, map}` if successful, otherwise `{:error, reason}`.","ref":"Cldr.Territory.html#info/1"},{"type":"function","title":"Example - Cldr.Territory.info/1","doc":"iex> Cldr.Territory.info(:GB)\n    {:ok,\n     %{\n       currency: [GBP: %{from: ~D[1694-07-27]}],\n       gdp: 2925000000000,\n       language_population: %{\n        \"ar\" => %{population_percent: 0.3},\n        \"bn\" => %{population_percent: 0.4},\n        \"cy\" => %{official_status: \"official_regional\", population_percent: 1.3},\n        \"de\" => %{population_percent: 9},\n        \"en\" => %{official_status: \"official\", population_percent: 98},\n        \"es\" => %{population_percent: 8},\n        \"fr\" => %{population_percent: 23},\n        \"ga\" => %{official_status: \"official_regional\", population_percent: 0.15},\n        \"gd\" => %{\n          official_status: \"official_regional\",\n          population_percent: 0.11,\n          writing_percent: 5\n        },\n        \"gu\" => %{population_percent: 2.9},\n        \"it\" => %{population_percent: 0.2},\n        \"kw\" => %{population_percent: 0.003},\n        \"lt\" => %{population_percent: 0.2},\n        \"pa\" => %{population_percent: 3.6},\n        \"pl\" => %{population_percent: 4},\n        \"pt\" => %{population_percent: 0.2},\n        \"sco\" => %{population_percent: 2.5, writing_percent: 5},\n        \"so\" => %{population_percent: 0.2},\n        \"ta\" => %{population_percent: 3.2},\n        \"tr\" => %{population_percent: 0.2},\n        \"ur\" => %{population_percent: 3.5},\n        \"zh-Hant\" => %{population_percent: 0.3},\n        \"en-Shaw\" => %{population_percent: 0}\n       },\n       literacy_percent: 99,\n       measurement_system: %{\n         default: :uksystem,\n         paper_size: :a4,\n         temperature: :uksystem\n       },\n       population: 65761100\n     }}\n\n    iex> Cldr.Territory.info(:\"155\")\n    {:error,\n     {Cldr.UnknownInformationError, \"No information available for :\\\"155\\\"\"}}","ref":"Cldr.Territory.html#info/1-example"},{"type":"function","title":"Cldr.Territory.info!/1","doc":"The same as `info/1`, but raises an exception if it fails.","ref":"Cldr.Territory.html#info!/1"},{"type":"function","title":"Example - Cldr.Territory.info!/1","doc":"iex> Cldr.Territory.info!(:GB)\n    %{\n      currency: [GBP: %{from: ~D[1694-07-27]}],\n      gdp: 2925000000000,\n      language_population: %{\n        \"ar\" => %{population_percent: 0.3},\n        \"bn\" => %{population_percent: 0.4},\n        \"cy\" => %{official_status: \"official_regional\", population_percent: 1.3},\n        \"de\" => %{population_percent: 9},\n        \"en\" => %{official_status: \"official\", population_percent: 98},\n        \"es\" => %{population_percent: 8},\n        \"fr\" => %{population_percent: 23},\n        \"ga\" => %{official_status: \"official_regional\", population_percent: 0.15},\n        \"gd\" => %{\n          official_status: \"official_regional\",\n          population_percent: 0.11,\n          writing_percent: 5\n        },\n        \"gu\" => %{population_percent: 2.9},\n        \"it\" => %{population_percent: 0.2},\n        \"kw\" => %{population_percent: 0.003},\n        \"lt\" => %{population_percent: 0.2},\n        \"pa\" => %{population_percent: 3.6},\n        \"pl\" => %{population_percent: 4},\n        \"pt\" => %{population_percent: 0.2},\n        \"sco\" => %{population_percent: 2.5, writing_percent: 5},\n        \"so\" => %{population_percent: 0.2},\n        \"ta\" => %{population_percent: 3.2},\n        \"tr\" => %{population_percent: 0.2},\n        \"ur\" => %{population_percent: 3.5},\n        \"zh-Hant\" => %{population_percent: 0.3},\n        \"en-Shaw\" => %{population_percent: 0}\n      },\n      literacy_percent: 99,\n      measurement_system: %{\n        default: :uksystem,\n        paper_size: :a4,\n        temperature: :uksystem\n      },\n      population: 65761100\n    }","ref":"Cldr.Territory.html#info!/1-example"},{"type":"function","title":"Cldr.Territory.known_subdivisions/1","doc":"Returns a map of all known territory subdivisions in a given locale.\n\n* `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/1`","ref":"Cldr.Territory.html#known_subdivisions/1"},{"type":"function","title":"Example - Cldr.Territory.known_subdivisions/1","doc":"=> Cldr.Territory.known_subdivisions(TestBackend.Cldr)\n    %{\n      \"ad02\" => \"Canillo\",\n      \"ad03\" => \"Encamp\",\n      \"ad04\" => \"La Massana\",\n      \"ad05\" => \"Ordino\",\n      \"ad06\" => \"Sant Julià de Lòria\",\n      \"ad07\" => \"Andorra la Vella\",\n      ...","ref":"Cldr.Territory.html#known_subdivisions/1-example"},{"type":"function","title":"Cldr.Territory.known_territories/1","doc":"Returns a map of all known territories in a given locale.\n\n* `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/1`","ref":"Cldr.Territory.html#known_territories/1"},{"type":"function","title":"Example - Cldr.Territory.known_territories/1","doc":"=> Cldr.Territory.known_territories(TestBackend.Cldr)\n    %{SN: %{standard: \"Senegal\"}, \"061\": %{standard: \"Polynesia\"},\n    BH: %{standard: \"Bahrain\"}, TM: %{standard: \"Turkmenistan\"},\n    \"009\": %{standard: \"Oceania\"}, CW: %{standard: \"Curaçao\"},\n    FR: %{standard: \"France\"}, TN: %{standard: \"Tunisia\"},\n    FI: %{standard: \"Finland\"}, BF: %{standard: \"Burkina Faso\"},\n    \"155\": %{standard: \"Western Europe\"}, GL: %{standard: \"Greenland\"},\n    VI: %{standard: \"U.S. Virgin Islands\"}, ZW: %{standard: \"Zimbabwe\"},\n    AR: %{standard: \"Argentina\"}, SG: %{standard: \"Singapore\"},\n    SZ: %{standard: \"Swaziland\"}, ID: %{standard: \"Indonesia\"},\n    NR: %{standard: \"Nauru\"}, RW: %{standard: \"Rwanda\"},\n    TR: %{standard: \"Turkey\"}, IS: %{standard: \"Iceland\"},\n    ME: %{standard: \"Montenegro\"}, AW: %{standard: \"Aruba\"},\n    PY: %{standard: \"Paraguay\"}, \"145\": %{standard: \"Western Asia\"},\n    CG: %{standard: \"Congo - Brazzaville\", variant: \"Congo (Republic)\"},\n    LT: %{standard: \"Lithuania\"}, SA: %{standard: \"Saudi Arabia\"},\n    MZ: %{standard: \"Mozambique\"}, NU: %{standard: \"Niue\"},\n    NG: %{standard: \"Nigeria\"}, CK: %{standard: \"Cook Islands\"},\n    ZM: %{standard: \"Zambia\"}, LK: %{standard: \"Sri Lanka\"},\n    UY: %{standard: \"Uruguay\"}, YE: %{standard: \"Yemen\"},\n    \"011\": %{standard: \"Western Africa\"},\n    CC: %{standard: \"Cocos (Keeling) Islands\"}, BY: %{standard: \"Belarus\"},\n    IL: %{standard: \"Israel\"}, KY: %{standard: \"Cayman Islands\"},\n    GN: %{standard: \"Guinea\"}, VN: %{standard: \"Vietnam\"},\n    PE: %{standard: \"Peru\"}, HU: %{standard: \"Hungary\"},\n    HN: %{standard: \"Honduras\"}, GI: %{standard: \"Gibraltar\"},\n    \"142\": %{standard: \"Asia\"}, \"029\": %{...}, ...}","ref":"Cldr.Territory.html#known_territories/1-example"},{"type":"function","title":"Cldr.Territory.known_territory_subdivisions/2","doc":"Returns a list of subdivisions of a given territory.","ref":"Cldr.Territory.html#known_territory_subdivisions/2"},{"type":"function","title":"Example - Cldr.Territory.known_territory_subdivisions/2","doc":"=> Cldr.Territory.known_territory_subdivisions(:GB, TestBackend.Cldr)\n    {:ok, [\"gbabc\", \"gbabd\", \"gbabe\", \"gbagb\", \"gbagy\", \"gband\", \"gbann\",\n    \"gbans\", \"gbbas\", \"gbbbd\", \"gbbdf\", \"gbbdg\", \"gbben\", \"gbbex\", \"gbbfs\",\n    \"gbbge\", \"gbbgw\", \"gbbir\", \"gbbkm\", \"gbbmh\", \"gbbne\", \"gbbnh\", \"gbbns\",\n    \"gbbol\", \"gbbpl\", \"gbbrc\", \"gbbrd\", \"gbbry\", \"gbbst\", \"gbbur\", \"gbcam\",\n    \"gbcay\", \"gbcbf\", \"gbccg\", \"gbcgn\", \"gbche\", \"gbchw\", \"gbcld\", \"gbclk\",\n    \"gbcma\", \"gbcmd\", \"gbcmn\", \"gbcon\", \"gbcov\", \"gbcrf\", \"gbcry\", \"gbcwy\",\n    \"gbdal\", \"gbdby\", \"gbden\", ...]}","ref":"Cldr.Territory.html#known_territory_subdivisions/2-example"},{"type":"function","title":"Cldr.Territory.parent/2","doc":"Lists parent(s) for the given territory code.\nReturns `{:ok, list}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#parent/2"},{"type":"function","title":"Example - Cldr.Territory.parent/2","doc":"iex> Cldr.Territory.parent(:GB)\n    {:ok, [:\"154\", :UN]}\n\n    iex> Cldr.Territory.parent(:ZZZ)\n    {:error, {Cldr.UnknownTerritoryError, \"The territory :ZZZ is unknown\"}}\n\n    iex> Cldr.Territory.parent(Cldr.get_locale())\n    {:error, {Cldr.UnknownChildrenError, \"The territory :\\\"001\\\" has no parent(s)\"}}","ref":"Cldr.Territory.html#parent/2-example"},{"type":"function","title":"Cldr.Territory.parent!/2","doc":"The same as `parent/2`, but raises an exception if it fails.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#parent!/2"},{"type":"function","title":"Example - Cldr.Territory.parent!/2","doc":"iex> Cldr.Territory.parent!(:GB)\n    [:\"154\", :UN]","ref":"Cldr.Territory.html#parent!/2-example"},{"type":"function","title":"Cldr.Territory.subdivision_aliases/0","doc":"Returns a map of available subdivision aliases.","ref":"Cldr.Territory.html#subdivision_aliases/0"},{"type":"function","title":"Example - Cldr.Territory.subdivision_aliases/0","doc":"iex#> Cldr.Territory.subdivision_aliases()\n    %{:uspr => :PR}","ref":"Cldr.Territory.html#subdivision_aliases/0-example"},{"type":"function","title":"Cldr.Territory.to_currency_code/2","doc":"A helper method to get a territory's currency code\nif a territory has multiply currencies then the oldest active currency is returned.\nReturns `{:ok, code}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#to_currency_code/2"},{"type":"function","title":"Example - Cldr.Territory.to_currency_code/2","doc":"iex> Cldr.Territory.to_currency_code(:US)\n    {:ok, :USD}\n\n    iex> Cldr.Territory.to_currency_code(\"cu\")\n    {:ok, :CUP}","ref":"Cldr.Territory.html#to_currency_code/2-example"},{"type":"function","title":"Cldr.Territory.to_currency_code!/2","doc":"The same as `to_currency_code/2`, but raises an exception if it fails.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#to_currency_code!/2"},{"type":"function","title":"Example - Cldr.Territory.to_currency_code!/2","doc":"iex> Cldr.Territory.to_currency_code!(:US)\n    :USD\n\n    iex> Cldr.Territory.to_currency_code!(:US, as: :charlist)\n    ~c\"USD\"\n\n    iex> Cldr.Territory.to_currency_code!(\"PS\")\n    :ILS\n\n    iex> Cldr.Territory.to_currency_code!(\"PS\", as: :binary)\n    \"ILS\"","ref":"Cldr.Territory.html#to_currency_code!/2-example"},{"type":"function","title":"Cldr.Territory.to_currency_codes/2","doc":"A helper method to get a territory's currency codes.\nReturns `{:ok, list}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#to_currency_codes/2"},{"type":"function","title":"Example - Cldr.Territory.to_currency_codes/2","doc":"iex> Cldr.Territory.to_currency_codes(:US)\n    {:ok, [:USD]}\n\n    iex> Cldr.Territory.to_currency_codes(\"ht\")\n    {:ok, [:USD, :HTG]}","ref":"Cldr.Territory.html#to_currency_codes/2-example"},{"type":"function","title":"Cldr.Territory.to_currency_codes!/2","doc":"The same as `to_currency_codes/2`, but raises an exception if it fails.\n\n* `options` are:\n  * `as: :atom`\n  * `as: :binary`\n  * `as: :charlist`","ref":"Cldr.Territory.html#to_currency_codes!/2"},{"type":"function","title":"Example - Cldr.Territory.to_currency_codes!/2","doc":"iex> Cldr.Territory.to_currency_codes!(:US)\n    [:USD]\n\n    iex> Cldr.Territory.to_currency_codes!(:US, as: :charlist)\n    [~c\"USD\"]\n\n    iex> Cldr.Territory.to_currency_codes!(\"PS\")\n    [:ILS, :JOD]\n\n    iex> Cldr.Territory.to_currency_codes!(\"PS\", as: :binary)\n    [\"ILS\", \"JOD\"]","ref":"Cldr.Territory.html#to_currency_codes!/2-example"},{"type":"function","title":"Cldr.Territory.to_unicode_flag/1","doc":"Unicode flag for the given territory code.\nReturns `{:ok, flag}` if successful, otherwise `{:error, reason}`.","ref":"Cldr.Territory.html#to_unicode_flag/1"},{"type":"function","title":"Example - Cldr.Territory.to_unicode_flag/1","doc":"iex> Cldr.Territory.to_unicode_flag(:US)\n    {:ok, \"🇺🇸\"}\n\n    iex> Cldr.Territory.to_unicode_flag(:EZ)\n    {:error, {Cldr.UnknownFlagError, \"The territory :EZ has no flag\"}}","ref":"Cldr.Territory.html#to_unicode_flag/1-example"},{"type":"function","title":"Cldr.Territory.to_unicode_flag!/1","doc":"The same as `to_unicode_flag/1`, but raises an exception if it fails.","ref":"Cldr.Territory.html#to_unicode_flag!/1"},{"type":"function","title":"Example - Cldr.Territory.to_unicode_flag!/1","doc":"iex> Cldr.Territory.to_unicode_flag!(:US)\n    \"🇺🇸\"","ref":"Cldr.Territory.html#to_unicode_flag!/1-example"},{"type":"function","title":"Cldr.Territory.translate_language_tag/3","doc":"Translate a LanguageTag.t into a localized string from one locale to another.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `options` are:\n  * `locale` is any configured locale. See `Cldr.known_locale_names/1`.\n    The default is `Cldr.get_locale/0`\n\n  * `style` is one of those returned by `Cldr.Territory.available_styles/0`.\n    The current styles are `:short`, `:standard` and `:variant`.\n    The default is `:standard`","ref":"Cldr.Territory.html#translate_language_tag/3"},{"type":"function","title":"Example - Cldr.Territory.translate_language_tag/3","doc":"iex> Cldr.Territory.translate_language_tag(Cldr.get_locale(), TestBackend.Cldr)\n    {:ok, \"world\"}\n\n    iex> Cldr.Territory.translate_language_tag(Cldr.get_locale(), TestBackend.Cldr, [locale: Cldr.Locale.new!(\"pt\", TestBackend.Cldr)])\n    {:ok, \"Mundo\"}","ref":"Cldr.Territory.html#translate_language_tag/3-example"},{"type":"function","title":"Cldr.Territory.translate_language_tag!/3","doc":"The same as `translate_language_tag/2`, but raises an exception if it fails.","ref":"Cldr.Territory.html#translate_language_tag!/3"},{"type":"function","title":"Example - Cldr.Territory.translate_language_tag!/3","doc":"iex> Cldr.Territory.translate_language_tag!(Cldr.get_locale(), TestBackend.Cldr)\n    \"world\"\n\n    iex> Cldr.Territory.translate_language_tag!(Cldr.get_locale(), TestBackend.Cldr, [locale: Cldr.Locale.new!(\"pt\", TestBackend.Cldr)])\n    \"Mundo\"","ref":"Cldr.Territory.html#translate_language_tag!/3-example"},{"type":"function","title":"Cldr.Territory.translate_subdivision/5","doc":"Translate a localized string from one locale to another.\nReturns `{:ok, String.t}` if successful, otherwise `{:error, reason}`.\n\n* `to_locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`","ref":"Cldr.Territory.html#translate_subdivision/5"},{"type":"function","title":"Example - Cldr.Territory.translate_subdivision/5","doc":"iex> Cldr.Territory.translate_subdivision(\"Cumbria\", \"en\", TestBackend.Cldr, \"pl\")\n    {:ok, \"Kumbria\"}\n\n    iex> Cldr.Territory.translate_subdivision(\"Cumbria\", \"en\", TestBackend.Cldr, \"bs\")\n    {:error, {Cldr.UnknownSubdivisionError, \"No subdivision translation for :gbcma could be found in locale :bs\"}}\n\n    iex> Cldr.Territory.translate_subdivision(\"Cumbria\", :zzz, TestBackend.Cldr)\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}\n\n    iex> Cldr.Territory.translate_subdivision(\"Cumbria\", \"en\", TestBackend.Cldr, \"zzz\")\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"Cldr.Territory.html#translate_subdivision/5-example"},{"type":"function","title":"Cldr.Territory.translate_subdivision!/5","doc":"The same as `translate_subdivision/3`, but raises an exception if it fails.","ref":"Cldr.Territory.html#translate_subdivision!/5"},{"type":"function","title":"Example - Cldr.Territory.translate_subdivision!/5","doc":"iex> Cldr.Territory.translate_subdivision!(\"Cumbria\", \"en\", TestBackend.Cldr, \"pl\")\n    \"Kumbria\"\n\n    #=> Cldr.Territory.translate_subdivision!(\"Cumbria\", \"en\", TestBackend.Cldr, \"bs\")\n    ** (Cldr.UnknownSubdivisionError) The locale \"bs\" has no translation for \"gbcma\".","ref":"Cldr.Territory.html#translate_subdivision!/5-example"},{"type":"function","title":"Cldr.Territory.translate_territory/5","doc":"Translate a localized string from one locale to another.\nReturns `{:ok, result}` if successful, otherwise `{:error, reason}`.\n\n* `to_locale` is any configured locale. See `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`","ref":"Cldr.Territory.html#translate_territory/5"},{"type":"function","title":"Example - Cldr.Territory.translate_territory/5","doc":"iex> Cldr.Territory.translate_territory(\"Reino Unido\", \"pt\", TestBackend.Cldr)\n    {:ok, \"United Kingdom\"}\n\n    iex> Cldr.Territory.translate_territory(\"United Kingdom\", \"en\", TestBackend.Cldr, \"pt\")\n    {:ok, \"Reino Unido\"}\n\n    iex> Cldr.Territory.translate_territory(\"Reino Unido\", :zzz, TestBackend.Cldr)\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}\n\n    iex> Cldr.Territory.translate_territory(\"United Kingdom\", \"en\", TestBackend.Cldr, \"zzz\")\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"Cldr.Territory.html#translate_territory/5-example"},{"type":"function","title":"Cldr.Territory.translate_territory!/5","doc":"The same as `translate_territory/3`, but raises an exception if it fails.","ref":"Cldr.Territory.html#translate_territory!/5"},{"type":"function","title":"Example - Cldr.Territory.translate_territory!/5","doc":"iex> Cldr.Territory.translate_territory!(\"Reino Unido\", \"pt\", TestBackend.Cldr)\n    \"United Kingdom\"\n\n    iex> Cldr.Territory.translate_territory!(\"United Kingdom\", \"en\", TestBackend.Cldr, \"pt\")\n    \"Reino Unido\"","ref":"Cldr.Territory.html#translate_territory!/5-example"},{"type":"exception","title":"Cldr.UnknownChildrenError","doc":"Exception raised when there is an invalid child.","ref":"Cldr.UnknownChildrenError.html"},{"type":"exception","title":"Cldr.UnknownFlagError","doc":"Exception raised when there is an invalid Flag.","ref":"Cldr.UnknownFlagError.html"},{"type":"exception","title":"Cldr.UnknownInformationError","doc":"Exception raised when there is a missing information.","ref":"Cldr.UnknownInformationError.html"},{"type":"exception","title":"Cldr.UnknownLanguageTagError","doc":"Exception raised when there is an invalid LanguageTag.t.","ref":"Cldr.UnknownLanguageTagError.html"},{"type":"exception","title":"Cldr.UnknownParentError","doc":"Exception raised when there is an invalid parent.","ref":"Cldr.UnknownParentError.html"},{"type":"exception","title":"Cldr.UnknownStyleError","doc":"Exception raised when there is an invalid style.","ref":"Cldr.UnknownStyleError.html"},{"type":"exception","title":"Cldr.UnknownSubdivisionError","doc":"Exception raised when there is a missing subdivision.","ref":"Cldr.UnknownSubdivisionError.html"},{"type":"extras","title":"Cldr for Territories","doc":"# Cldr for Territories\n\n![main](https://github.com/elixir-cldr/cldr_territories/actions/workflows/ci.yml/badge.svg?branch=main)","ref":"readme.html"},{"type":"extras","title":"Introduction and Getting Started - Cldr for Territories","doc":"`ex_cldr_territories` is an add-on library for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localization for territories.","ref":"readme.html#introduction-and-getting-started"},{"type":"extras","title":"Examples - Cldr for Territories","doc":"```elixir\niex> MyCldr.Territory.from_territory_code(:GB)\n{:ok, \"United Kingdom\"}\n\niex> MyCldr.Territory.translate_territory(\"Reino Unido\", \"pt\", \"en\")\n{:ok, \"UK\"}\n\niex> MyCldr.Territory.contains?(:EU, :GB)\nfalse\n\niex> MyCldr.Territory.contains?(:EU, :DE)\ntrue\n\niex> MyCldr.Territory.parent(:GB)\n{:ok, [:\"154\", :UN]}\n\niex> MyCldr.Territory.children(:EU)\n{:ok,\n [:AT, :BE, :CY, :CZ, :DE, :DK, :EE, :ES, :FI, :FR, :GR, :HR, :HU, :IE,\n  :IT, :LT, :LU, :LV, :MT, :NL, :PL, :PT, :SE, :SI, :SK, :BG, :RO]}\n\niex> MyCldr.Territory.info(:GB)\n{:ok,\n %{\n   currency: [GBP: %{from: ~D[1694-07-27]}],\n   gdp: 2925000000000,\n   language_population: %{\n     \"bn\" => %{population_percent: 0.67},\n     \"cy\" => %{official_status: \"official_regional\", population_percent: 0.77},\n     \"de\" => %{population_percent: 6},\n     \"el\" => %{population_percent: 0.33},\n     \"en\" => %{official_status: \"official\", population_percent: 99},\n     \"fr\" => %{population_percent: 19},\n     \"ga\" => %{official_status: \"official_regional\", population_percent: 0.026},\n     \"gd\" => %{\n       official_status: \"official_regional\",\n       population_percent: 0.099,\n       writing_percent: 5\n     },\n     \"it\" => %{population_percent: 0.33},\n     \"ks\" => %{population_percent: 0.19},\n     \"kw\" => %{population_percent: 0.003},\n     \"ml\" => %{population_percent: 0.035},\n     \"pa\" => %{population_percent: 0.79},\n     \"sco\" => %{population_percent: 2.7, writing_percent: 5},\n     \"syl\" => %{population_percent: 0.51},\n     \"yi\" => %{population_percent: 0.049},\n     \"zh-Hant\" => %{population_percent: 0.54}\n   },\n   literacy_percent: 99,\n   measurement_system: %{\n     default: :uksystem,\n     paper_size: :a4,\n     temperature: :uksystem\n   },\n   population: 65761100\n }}\n\niex> MyCldr.Territory.to_unicode_flag(:US)\n{:ok, \"🇺🇸\"}\n\niex> MyCldr.Territory.to_currency_code(:US)\n{:ok, :USD}\n```\n\nFor help in `iex`:\n\n```elixir\niex> h MyCldr.Territory.from_territory_code\n```","ref":"readme.html#examples"},{"type":"extras","title":"Documentation - Cldr for Territories","doc":"[hex documentation for ex_cldr](https://hexdocs.pm/ex_cldr/)\n\n[hex documentation for ex_cldr_territories](https://hexdocs.pm/ex_cldr_territories/)","ref":"readme.html#documentation"},{"type":"extras","title":"Installation - Cldr for Territories","doc":"Note that `:ex_cldr_territories` requires Elixir 1.12 or later.\n\nAdd `ex_cldr_territories` as a dependency to your `mix` project:\n\n```elixir\n    defp deps do\n      [\n        {:ex_cldr_territories, \"~> 2.9.0\"}\n      ]\n    end\n```\n\nthen retrieve `ex_cldr_territories` from [hex](https://hex.pm/packages/ex_cldr_territories):\n\n    mix deps.get\n    mix deps.compile\n\nIn order to use this library, a backend module for `ex_cldr` must be defined.  This is described in full in the `ex_cldr` [readme](https://hexdocs.pm/ex_cldr/readme.html#configuration).\nTo get started, define a backend module in your project as follows:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [:en],\n    providers: [Cldr.Territory]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE - Cldr for Territories","doc":"(The MIT License)\n\nCopyright (c) 2017 Benjamin Schultzer\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr Territories v2.9.0 May 14, 2024 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-9-0-may-14-2024"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 45](https://cldr.unicode.org/index/downloads/cldr-45) via [ex_cldr version 2.38.1](https://hex.pm/packages/ex_cldr/2.38.1)\n* Fixed typespec in `info/1` and `info!/1`, thanks to @jfpedroza.\n* Fixed typespec in `known_territory_subdivision/0`, thanks to @richard-ash.\n* Fixed compiler warnings for Elixir 1.16, thanks to @tomciopp.\n* Fixed compiler warnings for Elixir 1.17.\n* Require Elixir 1.12.0.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.8.1 July 18, 2023 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-8-1-july-18-2023"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fixed compiler warning for `from_subdivision_code/*`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.8.0 July 15, 2023 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-8-0-july-15-2023"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fixed compiler warnings for Elixir 1.15, thanks to @alappe.\n* Resolve subdivision aliases in `from_subdivision_code/*` and `from_subdivision_code!/*` and,\n  allow optional style to be passed to the underlying `from_territory_code/*` in cases where a subdivision is to be treated as a territory.\n* Added `subdivision_aliases/0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.7.0 May 5, 2023 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-7-0-may-5-2023"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43) via [ex_cldr version 2.37](https://hex.pm/packages/ex_cldr/2.37.0)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.6.0 January 14, 2023 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-6-0-january-14-2023"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 42](https://cldr.unicode.org/index/downloads/cldr-42) via [ex_cldr version 2.34](https://hex.pm/packages/ex_cldr/2.34.0)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.5.0 Octorber 24, 2022 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-5-0-octorber-24-2022"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.33](https://hex.pm/packages/ex_cldr/2.33.0)\n* Updates to support [CLDR release 41](https://cldr.unicode.org/index/downloads/cldr-41) via [ex_cldr version 2.28](https://hex.pm/packages/ex_cldr/2.28.0)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.4.1 Octorber 20nd, 2022 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-4-1-octorber-20nd-2022"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fixed spec for `known_territory_subdivisions/2` thanks to @zorbash","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.4.0 February 22nd, 2022 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-4-0-february-22nd-2022"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.3.0 October 27th, 2021 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-3-0-october-27th-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)\n\n* Replace deprecated `Cldr.Config.get_locale/2` and `Cldr.Config.known_locale_names/1` with the replacement versions in `Cldr.Locale.Loader`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Updates minimum Elixir version to 1.10 since this is the minimum supported by `ex_cldr` version 2.24 and later.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr Territories v2.3.0-rc.0 October 19th, 2021 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-3-0-rc-0-october-19th-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to `ex_cldr` version `2.24` which uses [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data\n\n* Both territories and territory subdivisions are now represented as atoms in the canonical form rather than the previous binary representation.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.2.2 May 11th, 2021 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-2-2-may-11th-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fix bug in `translate_territory!/4` [#16](https://github.com/Schultzer/cldr_territories/pull/16), thanks to @leandrocp.\n\n* Fix bug in `translate_subdivision!/4`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.2.1 May 10th, 2021 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-2-1-may-10th-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fix specs for `known_territories/1`, `known_subdivisions/1`, `from_subdivision_code/2,3` and `from_subdivision_code!/2,3` [#14](https://github.com/Schultzer/cldr_territories/issues/14)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.2.0 April 19th, 2021 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-2-0-april-19th-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Requires `ex_cldr` version `2.20` or later to use CLDR data version 39. As with all CLDR releases, underlying data can change and tests are updated to reflect those changes.\n\n* Added `known_subdivisions/1`, `known_territory_subdivisions/2`, `from_subdivision_code/3` and `translate_subdivision/4` to support subdivison, thansk to @mskv.\n\n* Improved proformance for `from_territory_code/2`, `from_subdivision_code/2`, `translate_territory/4` and `translate_subdivision/4`, thanks to @kipcole9.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.1.0 June 8th, 2020 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-1-0-june-8th-2020"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Requires `ex_cldr` version `2.14` or later to use CLDR data version 37. As with all CLDR releases, underlying data can change and tests are updated to reflect those changes.\n\n* Updated readme to reflect changes in EU composition and the updated data returned territories\n\n* CLDR 37 also reflects that the UK is no longer part of the EU.\n\n* Minimum version of Elixir required is 1.8 to align with the baseline `ex_cldr` library\n\n* Fix typespec leading to dialyzer errors\n\n* Update dependencies in development","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.0.1 May 1st, 2019 - Changelog","doc":"","ref":"changelog.html#cldr-territories-v2-0-1-may-1st-2019"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fix dialyzer errors thanks to @jeroenvisser101","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Territories v2.0.0 November 25st, 2018 - Changelog","doc":"This is the changelog for Cldr Territories v2.0.0 released on November 25th, 2018. For older changelogs please consult the release tag on [GitHub](https://github.com/schultzer/cldr_territories/tags)","ref":"changelog.html#cldr-territories-v2-0-0-november-25st-2018"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Move to a backend module structure with [ex_cldr](https://hex.pm/packages/ex_cldr) version 2.0","ref":"changelog.html#enhancements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}